import os
import logging
import asyncio
from datetime import datetime, timedelta
from telegram import Update, InlineKeyboardButton, InlineKeyboardMarkup
from telegram.ext import (
    ApplicationBuilder,
    CommandHandler,
    MessageHandler,
    CallbackQueryHandler,
    ContextTypes,
    filters
)
from telegram.error import TimedOut
from PIL import Image
import zipfile
import PyPDF2
import docx

# تنظیم لاگین
logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)
handler = logging.StreamHandler()
formatter = logging.Formatter('⏰ %(asctime)s - 🎯 %(levelname)s - 📝 %(message)s - 🌐 %(lineno)d')
handler.setFormatter(formatter)
logger.addHandler(handler)

# تنظیمات
TOKEN = "8002293154:AAHatjWP2A1ddBIKqWVtf4ZjRtXgn6-mDOs"
POPPLER_PATH = r"C:\poppler\poppler-23.11.0\Library\bin"
SUPPORTED_IMAGE_TYPES = {'.jpg', '.jpeg', '.png', '.webp'}
SUPPORTED_TEXT_TYPES = {'.txt', '.docx', '.pdf'}
TEMP_DIR = "./temp"
MAX_FILE_SIZE_MB = 50  # محدودیت تلگرام برای فایل‌ها
SEND_TIMEOUT_SECONDS = 300  # تایم‌اوت ارسال (5 دقیقه)
MAX_RETRIES = 3  # حداکثر تعداد تلاش برای ارسال
RETRY_DELAY_SECONDS = 5  # تأخیر بین تلاش‌ها
MAX_IMAGES = 5  # حداکثر تعداد تصاویر
CLEANUP_INTERVAL_HOURS = 4  # پاک‌سازی هر 4 ساعت
CLEANUP_AGE_HOURS = 1  # فقط فایل‌های قدیمی‌تر از 1 ساعت پاک بشن

# ایجاد دایرکتوری موقت اگر وجود نداشته باشه
if not os.path.exists(TEMP_DIR):
    os.makedirs(TEMP_DIR)

# منوی اصلی
def main_menu():
    return InlineKeyboardMarkup([
        [InlineKeyboardButton("📷 تصاویر به PDF", callback_data="images_to_pdf")],
        [InlineKeyboardButton("📑 PDF به PNG", callback_data="pdf_to_png")],
        [InlineKeyboardButton("📊 شمارش کلمات", callback_data="count_words")],
        [InlineKeyboardButton("📝 متن به TXT", callback_data="text_to_txt")],
        [InlineKeyboardButton("📄 متن به DOCX", callback_data="text_to_docx")]
    ])

# دکمه‌های بازگشت
def back_keyboard():
    return InlineKeyboardMarkup([[InlineKeyboardButton("🔙 بازگشت", callback_data="cancel")]])

# دکمه‌های تأیید
def confirm_keyboard():
    return InlineKeyboardMarkup([
        [InlineKeyboardButton("✅ بله", callback_data="confirm_yes"),
         InlineKeyboardButton("❌ خیر", callback_data="confirm_no")],
        [InlineKeyboardButton("🔙 بازگشت", callback_data="cancel")]
    ])

# تمیزکاری فایل‌ها (برای هر کاربر)
def cleanup(user_id):
    try:
        temp_files = [f for f in os.listdir(TEMP_DIR) if f.startswith(str(user_id))]
        now = datetime.now()
        threshold = now - timedelta(hours=CLEANUP_AGE_HOURS)
        for f in temp_files:
            file_path = os.path.join(TEMP_DIR, f)
            file_mtime = datetime.fromtimestamp(os.path.getmtime(file_path))
            if file_mtime < threshold:  # فقط فایل‌های قدیمی‌تر از 1 ساعت پاک بشن
                os.remove(file_path)
                logger.debug(f"🗑️ فایل قدیمی پاک شد: {file_path}")
        logger.debug(f"🗑️ فایل‌های موقت برای کاربر {user_id} بررسی شدند")
    except Exception as e:
        logger.error(f"❌ خطا در پاک‌سازی فایل‌ها: {str(e)}")

# تمیزکاری خودکار فایل‌های قدیمی
async def auto_cleanup():
    while True:
        try:
            now = datetime.now()
            threshold = now - timedelta(hours=CLEANUP_AGE_HOURS)
            for f in os.listdir(TEMP_DIR):
                file_path = os.path.join(TEMP_DIR, f)
                file_mtime = datetime.fromtimestamp(os.path.getmtime(file_path))
                if file_mtime < threshold:
                    os.remove(file_path)
                    logger.debug(f"🗑️ فایل قدیمی پاک شد: {file_path}")
            await asyncio.sleep(CLEANUP_INTERVAL_HOURS * 3600)  # هر 4 ساعت
        except Exception as e:
            logger.error(f"❌ خطا در پاک‌سازی خودکار: {str(e)}")
            await asyncio.sleep(3600)  # در صورت خطا، 1 ساعت صبر کن

# چک کردن اتصال به تلگرام
async def check_connection(update, context):
    try:
        await context.bot.get_me()
        logger.debug("✅ اتصال به تلگرام برقرار است")
        return True
    except Exception as e:
        logger.error(f"❌ خطا در چک کردن اتصال: {str(e)}")
        await update.message.reply_text("⚠️ اتصال به تلگرام برقرار نیست! لطفاً اینترنت خودت رو چک کن و دوباره امتحان کن:", reply_markup=main_menu())
        return False

# تبدیل تصاویر به PDF
def images_to_pdf(image_paths, pdf_name, user_id):
    try:
        images = [Image.open(path).convert("RGB") for path in image_paths]
        pdf_path = os.path.join(TEMP_DIR, f"{user_id}_{pdf_name}.pdf")
        images[0].save(pdf_path, "PDF", save_all=True, append_images=images[1:], quality=60, optimize=True)  # کاهش کیفیت
        logger.debug(f"PDF ایجاد شد: {pdf_path}")
        return pdf_path
    except Exception as e:
        logger.error(f"❌ خطا در تبدیل تصاویر به PDF: {str(e)}")
        raise

# تبدیل تصاویر به ZIP
def images_to_zip(image_paths, zip_name, user_id):
    try:
        zip_path = os.path.join(TEMP_DIR, f"{user_id}_{zip_name}.zip")
        with zipfile.ZipFile(zip_path, 'w', zipfile.ZIP_DEFLATED) as zipf:
            for idx, img_path in enumerate(image_paths):
                img = Image.open(img_path).convert("RGB")
                png_path = os.path.join(TEMP_DIR, f"{user_id}_temp_{idx}.png")
                img.save(png_path, "PNG", quality=60, optimize=True)  # کاهش کیفیت
                zipf.write(png_path, f"image_{idx}.png")
                os.remove(png_path)  # پاک کردن فایل PNG موقت
        logger.debug(f"ZIP ایجاد شد: {zip_path}")
        return zip_path
    except Exception as e:
        logger.error(f"❌ خطا در تبدیل تصاویر به ZIP: {str(e)}")
        raise

# تبدیل PDF به تصاویر PNG
def pdf_to_images(pdf_path, user_id):
    try:
        from pdf2image import convert_from_bytes
        images = convert_from_bytes(
            open(pdf_path, 'rb').read(),
            poppler_path=POPPLER_PATH,
            fmt="PNG",
            thread_count=2
        )
        image_paths = []
        for i, img in enumerate(images):
            img_path = os.path.join(TEMP_DIR, f"{user_id}_page_{i}.png")
            img.save(img_path, "PNG", quality=60, optimize=True)  # کاهش کیفیت
            image_paths.append(img_path)
        logger.debug(f"تصاویر PNG از PDF ایجاد شد: {image_paths}")
        return image_paths
    except Exception as e:
        logger.error(f"❌ خطا در تبدیل PDF به تصویر: {str(e)}")
        raise Exception(f"خطا در تبدیل PDF به PNG: {str(e)}")

# شمارش کلمات و خطوط
def count_words_lines(file_path):
    try:
        if file_path.lower().endswith('.txt'):
            with open(file_path, 'r', encoding='utf-8') as f:
                lines = f.readlines()
                return len(lines), sum(len(line.split()) for line in lines)
        elif file_path.lower().endswith('.docx'):
            doc = docx.Document(file_path)
            text = [para.text for para in doc.paragraphs if para.text]
            return len(text), sum(len(para.split()) for para in text)
        elif file_path.lower().endswith('.pdf'):
            with open(file_path, 'rb') as f:
                reader = PyPDF2.PdfReader(f)
                text = ''.join(page.extract_text() for page in reader.pages if page.extract_text())
                return len(text.splitlines()), len(text.split())
        return 0, 0
    except Exception as e:
        logger.error(f"❌ خطا در شمارش کلمات: {str(e)}")
        raise

# تبدیل متن به فایل TXT
def text_to_txt(text, file_name, user_id):
    try:
        file_path = os.path.join(TEMP_DIR, f"{user_id}_{file_name}.txt")
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(text)
        logger.debug(f"TXT ایجاد شد: {file_path}")
        return file_path
    except Exception as e:
        logger.error(f"❌ خطا در تبدیل متن به TXT: {str(e)}")
        raise

# تبدیل تکه‌های متن به فایل DOCX
def texts_to_docx(texts, file_name, user_id):
    try:
        file_path = os.path.join(TEMP_DIR, f"{user_id}_{file_name}.docx")
        doc = docx.Document()
        for text in texts:
            doc.add_paragraph(text)
        doc.save(file_path)
        logger.debug(f"DOCX ایجاد شد: {file_path}")
        return file_path
    except Exception as e:
        logger.error(f"❌ خطا در تبدیل متن به DOCX: {str(e)}")
        raise

# بررسی حجم فایل
async def check_file_size(file_path, user_id):
    file_size_mb = os.path.getsize(file_path) / (1024 * 1024)
    if file_size_mb > MAX_FILE_SIZE_MB:
        logger.warning(f"⚠️ حجم فایل ({file_size_mb:.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است برای کاربر {user_id}")
        return False
    return True

# ارسال فایل با مدیریت تلاش دوباره
async def send_file(update, file_path, filename, timeout=SEND_TIMEOUT_SECONDS, retries=MAX_RETRIES):
    for attempt in range(retries):
        try:
            async with asyncio.timeout(timeout):
                with open(file_path, 'rb') as file:
                    await update.message.reply_document(document=file, filename=filename)
                    logger.debug(f"📤 فایل ارسال شد: {filename}")
                    return
        except TimedOut as e:
            logger.warning(f"⏰ تایم‌اوت در ارسال فایل (تلاش {attempt + 1}/{retries}): {filename}")
            if attempt < retries - 1:
                await update.message.reply_text(f"⏳ تلاش {attempt + 1} ناموفق بود. دوباره تلاش می‌کنم...")
                await asyncio.sleep(RETRY_DELAY_SECONDS)
            else:
                logger.error(f"⏰ تمام تلاش‌ها برای ارسال فایل ناموفق بود: {filename}")
                await update.message.reply_text(
                    f"⏰ زمان ارسال فایل ({filename}) به پایان رسید حتی بعد از {retries} تلاش! لطفاً اینترنت رو چک کن یا دوباره امتحان کن:",
                    reply_markup=main_menu()
                )
                raise
        except Exception as e:
            logger.error(f"❌ خطا در ارسال فایل ({filename}): {str(e)}")
            await update.message.reply_text(
                f"❌ خطا در ارسال فایل ({filename}): {str(e)}. لطفاً دوباره امتحان کن:",
                reply_markup=main_menu()
            )
            raise

# دستور start
async def start(update: Update, context: ContextTypes.DEFAULT_TYPE):
    user_id = update.message.from_user.id
    logger.info(f"👤 کاربر {user_id} ربات را شروع کرد")
    await update.message.reply_text("🎉 به ربات تبدیل فایل خوش اومدی! 🛠️\nیکی از گزینه‌ها رو انتخاب کن:", reply_markup=main_menu())
    cleanup(user_id)

# مدیریت دکمه‌ها
async def button_handler(update: Update, context: ContextTypes.DEFAULT_TYPE):
    query = update.callback_query
    data = query.data
    user_id = query.from_user.id
    await query.answer()
    logger.info(f"👆 کاربر {user_id} روی دکمه {data} کلیک کرد")

    if data == "images_to_pdf":
        await query.edit_message_text("📷 لطفاً تصاویر (JPG, PNG, WEBP) رو بفرست:", reply_markup=back_keyboard())
        context.user_data['state'] = 'collecting_images'
        context.user_data['image_paths'] = []
    elif data == "pdf_to_png":
        await query.edit_message_text("📑 لطفاً فایل PDF رو بفرست:", reply_markup=back_keyboard())
        context.user_data['state'] = 'awaiting_pdf_for_png'
    elif data == "count_words":
        await query.edit_message_text("📊 لطفاً فایل متنی (TXT, DOCX, PDF) رو بفرست:", reply_markup=back_keyboard())
        context.user_data['state'] = 'awaiting_text_for_count'
    elif data == "text_to_txt":
        await query.edit_message_text("📝 لطفاً متن رو برای تبدیل به TXT بفرست:", reply_markup=back_keyboard())
        context.user_data['state'] = 'awaiting_text_for_txt'
    elif data == "text_to_docx":
        await query.edit_message_text("📄 لطفاً تکه‌های متن رو برای تبدیل به DOCX بفرست:", reply_markup=back_keyboard())
        context.user_data['state'] = 'collecting_texts'
        context.user_data['texts'] = []
    elif data == "cancel":
        cleanup(user_id)
        await query.edit_message_text("↩️ عملیات لغو شد! به منوی اصلی برگشتی:", reply_markup=main_menu())
        context.user_data.clear()
    elif data == "confirm_yes":
        if context.user_data.get('state') == 'collecting_images':
            if not context.user_data.get('image_paths'):
                await query.edit_message_text("⚠️ هیچ تصویری نفرستادی! لطفاً حداقل یه تصویر بفرست:", reply_markup=back_keyboard())
                return
            if len(context.user_data['image_paths']) > MAX_IMAGES:
                await query.edit_message_text(f"⚠️ تعداد تصاویر بیشتر از حد مجاز ({MAX_IMAGES}) است! لطفاً تعداد کمتری تصویر بفرست:", reply_markup=back_keyboard())
                return
            await query.edit_message_text("📝 لطفاً نام فایل (برای PDF و ZIP) رو وارد کن:")
            context.user_data['state'] = 'awaiting_file_name'
        elif context.user_data.get('state') == 'collecting_texts':
            if not context.user_data.get('texts'):
                await query.edit_message_text("⚠️ هیچ متنی نفرستادی! لطفاً حداقل یه تکه متن بفرست:", reply_markup=back_keyboard())
                return
            await query.edit_message_text("📝 لطفاً نام فایل (برای DOCX) رو وارد کن:")
            context.user_data['state'] = 'awaiting_docx_file_name'
    elif data == "confirm_no":
        cleanup(user_id)
        await query.edit_message_text("↩️ عملیات لغو شد! به منوی اصلی برگشتی:", reply_markup=main_menu())
        context.user_data.clear()

# مدیریت پیام‌ها و فایل‌ها
async def handle_message(update: Update, context: ContextTypes.DEFAULT_TYPE):
    user_id = update.message.from_user.id
    state = context.user_data.get('state')
    logger.info(f"📝 کاربر {user_id} پیام فرستاد: {update.message.text or 'فایل'}، حالت: {state}")

    # چک کردن اتصال قبل از هر عملیات سنگین
    if state in ['awaiting_file_name', 'awaiting_pdf_for_png', 'awaiting_docx_file_name', 'awaiting_text_for_txt']:
        if not await check_connection(update, context):
            return

    # حذف پیام قبلی وقتی تصویر یا متن جدید می‌فرسته
    if state in ['collecting_images', 'collecting_texts']:
        if 'last_message_id' in context.user_data:
            try:
                await context.bot.delete_message(chat_id=update.message.chat_id, message_id=context.user_data['last_message_id'])
            except Exception as e:
                logger.error(f"❌ خطا در حذف پیام قبلی: {str(e)}")

    # مدیریت نام فایل برای PDF و ZIP
    if state == 'awaiting_file_name':
        if update.message.text:
            image_paths = context.user_data.get('image_paths', [])
            if image_paths:
                try:
                    # تبدیل تصاویر به PDF
                    pdf_path = images_to_pdf(image_paths, update.message.text, user_id)
                    if not await check_file_size(pdf_path, user_id):
                        await update.message.reply_text(
                            f"⚠️ حجم فایل PDF ({os.path.getsize(pdf_path) / (1024 * 1024):.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                            reply_markup=main_menu()
                        )
                        cleanup(user_id)
                        return

                    # ارسال PDF
                    await update.message.reply_text("⏳ در حال ارسال PDF... لطفاً صبر کن!")
                    await send_file(update, pdf_path, f"{update.message.text}.pdf")

                    # تبدیل تصاویر به ZIP
                    zip_path = images_to_zip(image_paths, update.message.text, user_id)
                    if not await check_file_size(zip_path, user_id):
                        await update.message.reply_text(
                            f"⚠️ حجم فایل ZIP ({os.path.getsize(zip_path) / (1024 * 1024):.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                            reply_markup=main_menu()
                        )
                        cleanup(user_id)
                        return

                    # ارسال ZIP
                    await update.message.reply_text("⏳ در حال ارسال ZIP... لطفاً صبر کن!")
                    await send_file(update, zip_path, f"{update.message.text}.zip")

                    await update.message.reply_text("✅ تصاویر به PDF و ZIP تبدیل شدن! به منوی اصلی برمی‌گردم:", reply_markup=main_menu())
                except Exception as e:
                    logger.error(f"❌ خطای کلی در پردازش: {str(e)}", exc_info=True)
                    await update.message.reply_text(f"❌ خطا در پردازش: {str(e)}", reply_markup=main_menu())
            context.user_data.clear()
            cleanup(user_id)
        return

    # مدیریت نام فایل برای DOCX
    if state == 'awaiting_docx_file_name':
        if update.message.text:
            texts = context.user_data.get('texts', [])
            if texts:
                try:
                    # تبدیل تکه‌های متن به DOCX
                    docx_path = texts_to_docx(texts, update.message.text, user_id)
                    if not await check_file_size(docx_path, user_id):
                        await update.message.reply_text(
                            f"⚠️ حجم فایل DOCX ({os.path.getsize(docx_path) / (1024 * 1024):.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                            reply_markup=main_menu()
                        )
                        cleanup(user_id)
                        return

                    # ارسال DOCX
                    await send_file(update, docx_path, f"{update.message.text}.docx")

                    await update.message.reply_text("✅ متن‌ها به فایل DOCX تبدیل شدن! به منوی اصلی برمی‌گردم:", reply_markup=main_menu())
                except Exception as e:
                    logger.error(f"❌ خطای کلی در پردازش: {str(e)}", exc_info=True)
                    await update.message.reply_text(f"❌ خطا در پردازش: {str(e)}", reply_markup=main_menu())
            context.user_data.clear()
            cleanup(user_id)
        return

    # جمع‌آوری تصاویر
    if state == 'collecting_images':
        document = update.message.document
        if document and document.file_name.lower().endswith(tuple(SUPPORTED_IMAGE_TYPES)):
            file_name = document.file_name
            file_id = document.file_id
            file_size_mb = document.file_size / (1024 * 1024) if document.file_size else 0
            if file_size_mb > MAX_FILE_SIZE_MB:
                await update.message.reply_text(
                    f"⚠️ حجم فایل ({file_size_mb:.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                    reply_markup=back_keyboard()
                )
                return

            try:
                new_file = await context.bot.get_file(file_id)
                file_path = os.path.join(TEMP_DIR, f"{user_id}_{file_name}")
                await new_file.download_to_drive(file_path)
                context.user_data['image_paths'].append(file_path)
                message = await update.message.reply_text(f"✅ تصویر {file_name} دریافت شد! تصویر دیگه‌ای بفرست یا تأیید کن:", reply_markup=confirm_keyboard())
                context.user_data['last_message_id'] = message.message_id
            except Exception as e:
                logger.error(f"❌ خطا در دریافت فایل: {str(e)}", exc_info=True)
                await update.message.reply_text(f"❌ خطا در دریافت فایل: {str(e)}", reply_markup=back_keyboard())
        else:
            await update.message.reply_text("⚠️ لطفاً یه تصویر (JPG, PNG, WEBP) بفرست!", reply_markup=back_keyboard())
        return

    # جمع‌آوری تکه‌های متن برای DOCX
    if state == 'collecting_texts':
        if update.message.text:
            context.user_data['texts'].append(update.message.text)
            message = await update.message.reply_text(f"✅ تکه متن دریافت شد! تکه دیگه‌ای بفرست یا تأیید کن:", reply_markup=confirm_keyboard())
            context.user_data['last_message_id'] = message.message_id
        else:
            await update.message.reply_text("⚠️ لطفاً متن بفرست!", reply_markup=back_keyboard())
        return

    # تبدیل PDF به PNG (ارسال به صورت ZIP)
    if state == 'awaiting_pdf_for_png':
        document = update.message.document
        if document and document.file_name.lower().endswith('.pdf'):
            file_name = document.file_name
            file_id = document.file_id
            file_size_mb = document.file_size / (1024 * 1024) if document.file_size else 0
            if file_size_mb > MAX_FILE_SIZE_MB:
                await update.message.reply_text(
                    f"⚠️ حجم فایل ({file_size_mb:.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                    reply_markup=main_menu()
                )
                cleanup(user_id)
                return

            try:
                new_file = await context.bot.get_file(file_id)
                file_path = os.path.join(TEMP_DIR, f"{user_id}_{file_name}")
                await new_file.download_to_drive(file_path)

                images = pdf_to_images(file_path, user_id)
                zip_path = os.path.join(TEMP_DIR, f"{user_id}_pdf_to_png.zip")
                with zipfile.ZipFile(zip_path, 'w', zipfile.ZIP_DEFLATED) as zipf:
                    for img_path in images:
                        if not await check_file_size(img_path, user_id):
                            await update.message.reply_text(
                                f"⚠️ حجم تصویر ({os.path.getsize(img_path) / (1024 * 1024):.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                                reply_markup=main_menu()
                            )
                            cleanup(user_id)
                            return
                        zipf.write(img_path, os.path.basename(img_path))
                        os.remove(img_path)  # پاک کردن فایل موقت

                if not await check_file_size(zip_path, user_id):
                    await update.message.reply_text(
                        f"⚠️ حجم فایل ZIP ({os.path.getsize(zip_path) / (1024 * 1024):.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                        reply_markup=main_menu()
                    )
                    cleanup(user_id)
                    return

                # ارسال ZIP
                await update.message.reply_text("⏳ در حال ارسال ZIP... لطفاً صبر کن!")
                await send_file(update, zip_path, "pdf_to_png.zip")

                await update.message.reply_text("✅ PDF به تصاویر PNG تبدیل شد و توی ZIP فرستاده شد! به منوی اصلی برمی‌گردم:", reply_markup=main_menu())
            except Exception as e:
                logger.error(f"❌ خطای کلی در پردازش: {str(e)}", exc_info=True)
                await update.message.reply_text(f"❌ خطا در تبدیل PDF به PNG: {str(e)}", reply_markup=main_menu())
            context.user_data.clear()
            cleanup(user_id)
        else:
            await update.message.reply_text("⚠️ لطفاً یه فایل PDF بفرست!", reply_markup=back_keyboard())
        return

    # شمارش کلمات
    if state == 'awaiting_text_for_count':
        document = update.message.document
        if document and document.file_name.lower().endswith(tuple(SUPPORTED_TEXT_TYPES)):
            file_name = document.file_name
            file_id = document.file_id
            file_size_mb = document.file_size / (1024 * 1024) if document.file_size else 0
            if file_size_mb > MAX_FILE_SIZE_MB:
                await update.message.reply_text(
                    f"⚠️ حجم فایل ({file_size_mb:.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                    reply_markup=main_menu()
                )
                cleanup(user_id)
                return

            try:
                new_file = await context.bot.get_file(file_id)
                file_path = os.path.join(TEMP_DIR, f"{user_id}_{file_name}")
                await new_file.download_to_drive(file_path)

                line_count, word_count = count_words_lines(file_path)
                await update.message.reply_text(f"📊 تعداد خطوط: {line_count}\n📝 تعداد کلمات: {word_count}", reply_markup=main_menu())
                await update.message.reply_text("✅ شمارش انجام شد! به منوی اصلی برمی‌گردم:")
            except Exception as e:
                logger.error(f"❌ خطا در شمارش کلمات: {str(e)}", exc_info=True)
                await update.message.reply_text(f"❌ خطا در شمارش کلمات: {str(e)}", reply_markup=main_menu())
            context.user_data.clear()
            cleanup(user_id)
        else:
            await update.message.reply_text("⚠️ لطفاً یه فایل متنی (TXT, DOCX, PDF) بفرست!", reply_markup=back_keyboard())
        return

    # تبدیل متن به TXT
    if state == 'awaiting_text_for_txt':
        if update.message.text:
            try:
                file_path = text_to_txt(update.message.text, "user_text", user_id)
                if not await check_file_size(file_path, user_id):
                    await update.message.reply_text(
                        f"⚠️ حجم فایل ({os.path.getsize(file_path) / (1024 * 1024):.2f} MB) از حد مجاز ({MAX_FILE_SIZE_MB} MB) بیشتر است!",
                        reply_markup=main_menu()
                    )
                    cleanup(user_id)
                    return
                await send_file(update, file_path, "user_text.txt")
                await update.message.reply_text("✅ متن به فایل TXT تبدیل شد! به منوی اصلی برمی‌گردم:", reply_markup=main_menu())
            except Exception as e:
                logger.error(f"❌ خطا در تبدیل متن به TXT: {str(e)}", exc_info=True)
                await update.message.reply_text(f"❌ خطا در تبدیل متن به TXT: {str(e)}", reply_markup=main_menu())
            context.user_data.clear()
            cleanup(user_id)
        return

    await update.message.reply_text("⚠️ لطفاً از منو یه گزینه انتخاب کن:", reply_markup=main_menu())
    cleanup(user_id)

# اجرای ربات
def main():
    app = ApplicationBuilder().token(TOKEN).build()

    app.add_handler(CommandHandler("start", start))
    app.add_handler(CallbackQueryHandler(button_handler))
    app.add_handler(MessageHandler(filters.Document.ALL | filters.TEXT, handle_message))

    # شروع پاک‌سازی خودکار
    asyncio.ensure_future(auto_cleanup())

    logger.info("🚀 ربات در حال شروع است...")
    app.run_polling()

if __name__ == "__main__":
    main()